@@ -9,19 +9,17 @@ import (
 	"github.com/open-cluster-management/work/pkg/spoke/controllers/finalizercontroller"
 	"github.com/open-cluster-management/work/pkg/spoke/controllers/manifestcontroller"
 	"github.com/open-cluster-management/work/pkg/spoke/controllers/statuscontroller"
+	"sigs.k8s.io/controller-runtime/pkg/client/apiutil"
 
 	"github.com/openshift/library-go/pkg/controller/controllercmd"
 	"github.com/spf13/cobra"
 	apiextensionsclient "k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset"
-	"k8s.io/client-go/discovery"
-	cacheddiscovery "k8s.io/client-go/discovery/cached"
 	"k8s.io/client-go/dynamic"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/tools/clientcmd"
 
 	workclientset "github.com/open-cluster-management/api/client/work/clientset/versioned"
 	workinformers "github.com/open-cluster-management/api/client/work/informers/externalversions"
-	"github.com/open-cluster-management/work/pkg/spoke/resource"
 )
 
 // WorkloadAgentOptions defines the flags for workload agent
@@ -78,15 +76,10 @@ func (o *WorkloadAgentOptions) RunWorkloadAgent(ctx context.Context, controllerC
 		return err
 	}
 	spokeWorkInformerFactory := workinformers.NewSharedInformerFactory(spokeWorkClient, 5*time.Minute)
-	// Start restmapper gorountine that refresh cached APIGroupResources in the memory
-	// using discovery client
-	spokeDiscoveryClient, err := discovery.NewDiscoveryClientForConfig(spokeRestConfig)
+	restMapper, err := apiutil.NewDynamicRESTMapper(spokeRestConfig, apiutil.WithLazyDiscovery)
 	if err != nil {
 		return err
 	}
-	cachedSpokeDiscoveryClient := cacheddiscovery.NewMemCacheClient(spokeDiscoveryClient)
-	restMapper := resource.NewMapper(cachedSpokeDiscoveryClient)
-	go restMapper.Run(ctx.Done())
 
 	manifestWorkController := manifestcontroller.NewManifestWorkController(
 		ctx,
